@@ -15,7 +15,7 @@ here = pathlib.Path(__file__).parent.resolve()
 # Get the long description from the README file
 long_description = (here / "readme.md").read_text(encoding="utf-8")
 
-_VLSIR_VERSION = "1.0.0"
+_VLSIR_VERSION = "2.0.0"
 
 setup(
     name="sitepdks",
@@ -33,6 +33,6 @@ setup(
         f"asap7-hdl21=={_VLSIR_VERSION}",
     ],
     extras_require={
-        "dev": ["pytest==5.2", "coverage", "pytest-cov", "black==19.10b0", "twine"]
+        "dev": ["pytest==7.1", "coverage", "pytest-cov", "black==22.6", "twine"]
     },
 )
