@@ -8,6 +8,7 @@ from typing import List
 # Import all the defined passes
 from .elaborators import (
     GeneratorElaborator,
+    InstBundleElaborator,
     Orphanage,
     ConnTypes,
     BundleFlattener,
@@ -18,19 +19,20 @@ from .elaborators import (
 
 
 class ElabPass(Enum):
-    """ 
+    """
     # Enumerated Elaborator Passes
 
-    Each has a `value` attribute which is an `Elaborator` class, 
-    and a `name` attribute which is a (Python-enum-style) capitalized name. 
+    Each has a `value` attribute which is an `Elaborator` class,
+    and a `name` attribute which is a (Python-enum-style) capitalized name.
 
-    Typical usage involves arranging several `ElabPass` in a list 
-    to be performed in-order. 
-    The `default` class-method produces the default such list. 
+    Typical usage involves arranging several `ElabPass` in a list
+    to be performed in-order.
+    The `default` class-method produces the default such list.
     """
 
     RUN_GENERATORS = GeneratorElaborator
     ORPHANAGE = Orphanage
+    INSTANCE_BUNDLES = InstBundleElaborator
     RESOLVE_PORT_REFS = ResolvePortRefs
     CONN_TYPES = ConnTypes
     FLATTEN_BUNDLES = BundleFlattener
@@ -39,6 +41,10 @@ class ElabPass(Enum):
 
     @classmethod
     def default(cls) -> List["ElabPass"]:
-        """ Return the default ordered Elaborator Passes. """
+        """Return the default ordered Elaborator Passes."""
         # Returns each in definition order, then a final few tests.
         return list(ElabPass) + [ElabPass.CONN_TYPES, ElabPass.ORPHANAGE]
+
+    @property
+    def elaborate(self):
+        return self.value.elaborate
