@@ -8,19 +8,32 @@ and an `hdl21pdk.netlist` method for converting process-portable `hdl21.Primitiv
 The primitive components of the ASAP7 PDK are comprised solely of core Mos transistors `{n,p}mos_{rvt,lvt,slvt,sram}`. 
 
 FIXME!: Unlike the common subckt-based models provided by physical PDKs, the ASAP7 transistors are provided solely 
-as BSIM-CMG `.model` definitions. These are represented in the `vlsir` proto-schema as (FIXME: ...)
+as BSIM-CMG `.model` definitions. These are represented as (FIXME: ...)
 
 """
 
 import copy
-from typing import Union
+from typing import Union, Optional
 from types import SimpleNamespace
 from dataclasses import asdict
 
+from pydantic.dataclasses import dataclass
+
 import hdl21 as h
+from hdl21.pdk import PdkInstallation
 from hdl21.primitives import Mos, MosType, MosVth, MosParams
 
 
+@dataclass
+class Install(PdkInstallation):
+    ...  # No content
+
+
+# The optional external-data installation.
+# Set by an instantiator of `Install`, if available.
+install: Optional[Install] = None
+
+
 # Collected `ExternalModule`s are stored in the `modules` namespace
 modules = SimpleNamespace()
 
@@ -47,7 +60,7 @@ for tp, tpname in _mos_typenames.items():
             name=modname,
             desc=f"ASAP7 PDK Mos {modname}",
             port_list=copy.deepcopy(Mos.port_list),
-            paramtype=object,
+            paramtype=dict,
         )
 
         # Add it to the `params => ExternalModules` lookup table
@@ -58,13 +71,13 @@ for tp, tpname in _mos_typenames.items():
 
 
 class Asap7Walker(h.HierarchyWalker):
-    """ Hierarchical Walker, converting `h.Primitive` instances to process-defined `ExternalModule`s. """
+    """Hierarchical Walker, converting `h.Primitive` instances to process-defined `ExternalModule`s."""
 
     def __init__(self):
         self.mos_modcalls = dict()
 
     def visit_instance(self, inst: h.Instance):
-        """ Replace instances of `h.Primitive` with our `ExternalModule`s """
+        """Replace instances of `h.Primitive` with our `ExternalModule`s"""
         if isinstance(inst.of, h.PrimitiveCall):
             inst.of = self.replace_primitive(inst.of)
             return
@@ -81,14 +94,14 @@ class Asap7Walker(h.HierarchyWalker):
         return primcall
 
     def mos_module(self, params: MosParams) -> h.ExternalModule:
-        """ Retrieve or create an `ExternalModule` for a MOS of parameters `params`. """
+        """Retrieve or create an `ExternalModule` for a MOS of parameters `params`."""
         mod = _mos_modules.get((params.tp, params.vth), None)
         if mod is None:
             raise RuntimeError(f"No Mos module {modname}")
         return mod
 
     def mos_module_call(self, params: MosParams) -> h.ExternalModuleCall:
-        """ Retrieve or create a `Call` for MOS parameters `params`."""
+        """Retrieve or create a `Call` for MOS parameters `params`."""
         # First check our cache
         if params in self.mos_modcalls:
             return self.mos_modcalls[params]
@@ -108,8 +121,6 @@ class Asap7Walker(h.HierarchyWalker):
         return modcall
 
 
-def compile(src: h.proto.Package) -> h.proto.Package:
-    """ Compile proto-Package `src` to the ASAP7 technology """
-    ns = h.from_proto(src)
-    Asap7Walker().visit_namespace(ns)
-    return h.to_proto(ns)
+def compile(src: h.Elaboratables) -> None:
+    """Compile `src` to the ASAP7 technology"""
+    return Asap7Walker().visit_elaboratables(src)
